package javax.swing.plaf.metal;

import java.awt.Insets;
import java.awt.BasicStroke;
import java.awt.Graphics2D;
import java.awt.Graphics;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.awt.Rectangle;
import javax.swing.plaf.basic.BasicProgressBarUI;

public class MetalProgressBarUI extends BasicProgressBarUI
{
    private Rectangle innards;
    private Rectangle box;
    
    public MetalProgressBarUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new MetalProgressBarUI();
    }
    
    public void paintDeterminate(Graphics g, JComponent c) {
        super.paintDeterminate(g, c);
        if (!(g instanceof Graphics2D)) {
            return;
        }
        if (this.progressBar.isBorderPainted()) {
            Insets insets = this.progressBar.getInsets();
            int width = this.progressBar.getWidth() - (insets.left + insets.right);
            int height = this.progressBar.getHeight() - (insets.top + insets.bottom);
            int amountFull = this.getAmountFull(insets, width, height);
            int leftToRight = MetalUtils.isLeftToRight(c);
            int left = insets.left;
            int top = insets.top;
            int n = insets.left + width - 1;
            int n2 = insets.top + height - 1;
            Graphics2D graphics2D = (Graphics2D)g;
            graphics2D.setStroke(new BasicStroke(1.0f));
            if (this.progressBar.getOrientation() == 0) {
                graphics2D.setColor(MetalLookAndFeel.getControlShadow());
                graphics2D.drawLine(left, top, n, top);
                if (amountFull > 0) {
                    graphics2D.setColor(MetalLookAndFeel.getPrimaryControlDarkShadow());
                    if (!(leftToRight == 0)) {
                        graphics2D.drawLine(left, top, left + amountFull - 1, top);
                    }
                    else {
                        graphics2D.drawLine(n, top, n - amountFull + 1, top);
                        if (this.progressBar.getPercentComplete() != 1.0) {
                            graphics2D.setColor(MetalLookAndFeel.getControlShadow());
                        }
                    }
                }
                graphics2D.drawLine(left, top, left, n2);
            }
            else {
                graphics2D.setColor(MetalLookAndFeel.getControlShadow());
                graphics2D.drawLine(left, top, left, n2);
                if (amountFull > 0) {
                    graphics2D.setColor(MetalLookAndFeel.getPrimaryControlDarkShadow());
                    graphics2D.drawLine(left, n2, left, n2 - amountFull + 1);
                }
                graphics2D.setColor(MetalLookAndFeel.getControlShadow());
                if (this.progressBar.getPercentComplete() == 1.0) {
                    graphics2D.setColor(MetalLookAndFeel.getPrimaryControlDarkShadow());
                }
                graphics2D.drawLine(left, top, n, top);
            }
        }
        return;
    }
    
    public void paintIndeterminate(Graphics g, JComponent c) {
        super.paintIndeterminate(g, c);
        if (!this.progressBar.isBorderPainted() || !(g instanceof Graphics2D)) {
            return;
        }
        Insets insets = this.progressBar.getInsets();
        int width = this.progressBar.getWidth() - (insets.left + insets.right);
        int height = this.progressBar.getHeight() - (insets.top + insets.bottom);
        this.getAmountFull(insets, width, height);
        MetalUtils.isLeftToRight(c);
        Rectangle box = this.getBox(null);
        int left = insets.left;
        int top = insets.top;
        int n = insets.left + width - 1;
        int n2 = insets.top + height - 1;
        Graphics2D graphics2D = (Graphics2D)g;
        graphics2D.setStroke(new BasicStroke(1.0f));
        if (this.progressBar.getOrientation() == 0) {
            graphics2D.setColor(MetalLookAndFeel.getControlShadow());
            graphics2D.drawLine(left, top, n, top);
            graphics2D.drawLine(left, top, left, n2);
            graphics2D.setColor(MetalLookAndFeel.getPrimaryControlDarkShadow());
            graphics2D.drawLine(box.x, top, box.x + box.width - 1, top);
        }
        else {
            graphics2D.setColor(MetalLookAndFeel.getControlShadow());
            graphics2D.drawLine(left, top, left, n2);
            graphics2D.drawLine(left, top, n, top);
            graphics2D.setColor(MetalLookAndFeel.getPrimaryControlDarkShadow());
            graphics2D.drawLine(left, box.y, left, box.y + box.height - 1);
        }
        return;
    }
}
